separators = {}

separators['af'] = separators['be'] = separators['bg'] = separators['cs'] = separators['de-AT'] = separators['en-FI'] = separators['en-SE'] = separators['en-ZA'] = separators['es-CR'] = separators['et'] = separators['fi'] = separators['fr'] = separators['hu'] = separators['ka'] = separators['kk'] = separators['ky'] = separators['lt'] = separators['lv'] = separators['nb'] = separators['pl'] = separators['pt-AO'] = separators['pt-CV'] = separators['pt-GW'] = separators['pt-MO'] = separators['pt-MZ'] = separators['pt-PT'] = separators['pt-ST'] = separators['pt-TL'] = separators['ru'] = separators['sk'] = separators['sq'] = separators['sv'] = separators['uk'] = separators['uz'] = ', '

separators['am'] = separators['ar'] = separators['bn'] = separators['cy'] = separators['en'] = separators['es-419'] = separators['es-CU'] = separators['es-DO'] = separators['es-GT'] = separators['es-HN'] = separators['es-MX'] = separators['es-NI'] = separators['es-PA'] = separators['es-PE'] = separators['es-PR'] = separators['es-SV'] = separators['es-US'] = separators['fa'] = separators['fil'] = separators['ga'] = separators['gu'] = separators['he'] = separators['hi'] = separators['ja'] = separators['kn'] = separators['ko'] = separators['ml'] = separators['mn'] = separators['mr'] = separators['ms'] = separators['my'] = separators['ne'] = separators['pa'] = separators['root'] = separators['si'] = separators['sw'] = separators['ta'] = separators['te'] = separators['th'] = separators['to'] = separators['ur'] = separators['zh'] = separators['zu'] = '.,'

separators['ar-DZ'] = separators['ar-LB'] = separators['ar-LY'] = separators['ar-MA'] = separators['ar-MR'] = separators['ar-TN'] = separators['az'] = separators['bs'] = separators['ca'] = separators['da'] = separators['de'] = separators['el'] = separators['en-150'] = separators['en-AT'] = separators['en-BE'] = separators['en-CH'] = separators['en-DE'] = separators['en-DK'] = separators['en-NL'] = separators['en-SI'] = separators['es'] = separators['eu'] = separators['fo'] = separators['fr-BE'] = separators['fr-LU'] = separators['fr-MA'] = separators['gl'] = separators['hr'] = separators['hy'] = separators['id'] = separators['is'] = separators['it'] = separators['km'] = separators['lo'] = separators['mk'] = separators['ms-BN'] = separators['nl'] = separators['pt'] = separators['ro'] = separators['sl'] = separators['sr'] = separators['sw-CD'] = separators['tr'] = separators['vi'] = ',.'


separators['de-CH'] = separators['de-LI'] = separators['it-CH'] = '.\''


separators['fr-CH'] = '. '
